require("defines")

-- Returns the array of distance bonuses based on the given base value.
local function get_distance_bonuses_based_on_value(base_value)
	local bonuses = {}
	bonuses[1] = base_value * 0.5
	bonuses[2] = base_value
	bonuses[3] = base_value * 2
	bonuses[4] = base_value * 4
	return bonuses
end
-- Loot distance bonuses.
local loot_distance_bonuses = get_distance_bonuses_based_on_value(2)

---------------------------------------------------------

-- Sets the loot pickup distance for the given force according to the given long mine research level.
local function set_loot_distance(force, level)
	force.character_loot_pickup_distance_bonus = loot_distance_bonuses[level]
end

-- Look up table for mapping function for each researched technology name.
local research_finished_functions_lookup =
{
	-- Long loot.
	[long_loot_research.names.technology.long_loot_1] = function(force) set_loot_distance(force, 1) end,
	[long_loot_research.names.technology.long_loot_2] = function(force) set_loot_distance(force, 2) end,
	[long_loot_research.names.technology.long_loot_3] = function(force) set_loot_distance(force, 3) end,
	[long_loot_research.names.technology.long_loot_4] = function(force) set_loot_distance(force, 4) end,
}

-- Sets the team loot pickup distance after a long loot research has completed.
script.on_event(defines.events.on_research_finished, function(event)
	local func = research_finished_functions_lookup[event.research.name]
	if func then
		func(event.research.force)
	end
end)