require("defines")

-- Returns the array of distance bonuses based on the given base value.
local function get_distance_bonuses_based_on_value(base_value)
	local bonuses = {}
	bonuses[1] = base_value * 0.5
	bonuses[2] = base_value
	bonuses[3] = base_value * 2
	bonuses[4] = base_value * 4
	return bonuses
end
-- Mine distance bonuses.
local mine_distance_bonuses = get_distance_bonuses_based_on_value(2.7)

---------------------------------------------------------

-- Sets the mine distance for the given force according to the given long mine research level.
local function set_mine_distance(force, level)
	force.character_resource_reach_distance_bonus = mine_distance_bonuses[level]
end

-- Look up table for mapping function for each researched technology name.
local research_finished_functions_lookup =
{
	-- Long mine.
	[long_mine_research.names.technology.long_mine_1] = function(force) set_mine_distance(force, 1) end,
	[long_mine_research.names.technology.long_mine_2] = function(force) set_mine_distance(force, 2) end,
	[long_mine_research.names.technology.long_mine_3] = function(force) set_mine_distance(force, 3) end,
	[long_mine_research.names.technology.long_mine_4] = function(force) set_mine_distance(force, 4) end,
}

-- Sets the team mine distance after a long mine research has completed.
script.on_event(defines.events.on_research_finished, function(event)
	local func = research_finished_functions_lookup[event.research.name]
	if func then
		func(event.research.force)
	end
end)