require("defines")

-- Returns the array of distance bonuses based on the given base value.
local function get_distance_bonuses_based_on_value(base_value)
	local bonuses = {}
	bonuses[1] = base_value * 0.5
	bonuses[2] = base_value
	bonuses[3] = base_value * 2
	bonuses[4] = base_value * 4
	return bonuses
end
-- Pickup distance bonuses.
local pickup_distance_bonuses = get_distance_bonuses_based_on_value(1)

---------------------------------------------------------

-- Sets the item pickup distance for the given force according to the given long pickup research level.
local function set_pickup_distance(force, level)
	force.character_item_pickup_distance_bonus = pickup_distance_bonuses[level]
end

-- Look up table for mapping function for each researched technology name.
local research_finished_functions_lookup =
{
	-- Long item pickup.
	[long_pickup_research.names.technology.long_pickup_1] = function(force) set_pickup_distance(force, 1) end,
	[long_pickup_research.names.technology.long_pickup_2] = function(force) set_pickup_distance(force, 2) end,
	[long_pickup_research.names.technology.long_pickup_3] = function(force) set_pickup_distance(force, 3) end,
	[long_pickup_research.names.technology.long_pickup_4] = function(force) set_pickup_distance(force, 4) end,
}

-- Sets the team item pickup distance after a long pickup research has completed.
script.on_event(defines.events.on_research_finished, function(event)
	local func = research_finished_functions_lookup[event.research.name]
	if func then
		func(event.research.force)
	end
end)