require("config")

function init()
	if not global.mapview then 
		global.mapview = {}
	end
	for i, player in pairs(game.players) do
		if global.mapview[i] == nil then
			global.mapview[i] = string2bool(player.game_view_settings.show_minimap)
		end
	end
end

function toggle_view(player_index, view)
	local settings = game.players[player_index].game_view_settings
	if string2bool(settings[view]) then
		settings[view] = false
	else
		settings[view] = true
	end
end

function toggle_view_map(event)
	toggle_view(event.player_index, "show_minimap")
	global.mapview[event.player_index] = string2bool(game.players[event.player_index].game_view_settings.show_minimap)
end

function toggle_view_research(event)
	toggle_view(event.player_index, "show_research_info")
end

function toggle_view_toolbar(event)
	toggle_view(event.player_index, "show_controller_gui")
end

function toggle_view_alerts(event)
	-- toggle_view(event.player_index, "show_alert_gui")
	-- workaround for 0.14 bug https://forums.factorio.com/39511
	local settings = game.players[event.player_index].game_view_settings
	if string2bool(settings["show_alertgui"]) then
		settings["show_alert_gui"] = false
	else
		settings["show_alert_gui"] = true
	end
end

if viewsettings.enable_minimap_hotkey then
	script.on_event("toggle_view_map", toggle_view_map)
end

if viewsettings.enable_research_hotkey then
	script.on_event("toggle_view_research", toggle_view_research)
end

if viewsettings.enable_toolbar_hotkey then
	script.on_event("toggle_view_toolbar", toggle_view_toolbar)
end

if viewsettings.enable_alerts_hotkey then
	script.on_event("toggle_view_alerts", toggle_view_alerts)
end

function string2bool(s) -- workaround for bug https://forums.factorio.com/39511
	if s == "true" then
		return true
	end
	if s == "false" then
		return false
	end
	return nil
end

function set_map_view(player, state)
	if string2bool(player.game_view_settings.show_minimap) ~= state then
		toggle_view(player.index, "show_minimap")
	end
end

function to_toggle(selected)
	if viewsettings.hide_minimap_on_logistic_chests and selected.type == "logistic-container" then
		return true
	end
	if viewsettings.hide_minimap_on_roboports and selected.type == "roboport" then
		return true
	end
	if viewsettings.hide_minimap_on_locomotives and selected.type == "locomotive" then
		return true
	end
	if viewsettings.hide_minimap_on_cargo_wagons and selected.type == "cargo-wagon" then
		return true
	end
	return false
end

function updated_selected(event)
	for i, player in pairs(game.players) do
		if global.mapview[i] then
			if player.selected and to_toggle(player.selected) then
				set_map_view(player, false)
			else
				set_map_view(player, true)
			end
		end
	end
end

if viewsettings.hide_minimap_on_logistic_chests or viewsettings.hide_minimap_on_roboports or viewsettings.hide_minimap_on_locomotives or viewsettings.hide_minimap_on_cargo_wagons then
	script.on_event(defines.events.on_tick, updated_selected)
end

script.on_init(init)
script.on_configuration_changed(init)
script.on_event(defines.events.on_player_created, init)